@@ -6,6 +6,7 @@ import click
 from yojenkins.__main__ import stage
 from yojenkins.cli import cli_decorators, cli_stage
 from yojenkins.cli.cli_utility import set_debug_log_level
+from yojenkins.utility.utility import translate_kwargs
 
 
 @stage.command(short_help='\tStage information')
@@ -18,11 +19,24 @@ from yojenkins.cli.cli_utility import set_debug_log_level
 @click.option('-u', '--url', type=str, required=False, help='Build URL (No job info needed)')
 @click.option('--latest', type=bool, required=False, is_flag=True, help='Latest build (Replaces --number)')
 @click.pass_context
-def info(ctx, debug, pretty, yaml, xml, toml, profile, name, job, number, url, latest):
-    """Stage information"""
+def info(ctx, debug, **kwargs):
+    """Stage information
+
+    USAGE NOTES:
+
+    \b
+        - You must either sepcify the job with its build number
+          or the direct URl to the build
+
+    EXAMPLE:
+
+    \b
+    - yojenkins stage info my-build-stage --job my-job --latest
+    - yojenkins stage info stage-name --build_url http://localhost:8080/job/my-job/3/ --pretty
+    """
     set_debug_log_level(debug)
-    if job or url:
-        cli_stage.info(pretty, yaml, xml, toml, profile, name, job, number, url, latest)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_stage.info(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
 
@@ -36,11 +50,11 @@ def info(ctx, debug, pretty, yaml, xml, toml, profile, name, job, number, url, l
 @click.option('-u', '--url', type=str, required=False, help='Build URL (No job info needed)')
 @click.option('--latest', type=bool, required=False, is_flag=True, help='Latest build (Replaces --number)')
 @click.pass_context
-def status(ctx, debug, profile, name, job, number, url, latest):
+def status(ctx, debug, **kwargs):
     """Stage status text"""
     set_debug_log_level(debug)
-    if job or url:
-        cli_stage.status(profile, name, job, number, url, latest)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_stage.status(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
 
@@ -56,11 +70,11 @@ def status(ctx, debug, profile, name, job, number, url, latest):
 @click.option('-u', '--url', type=str, required=False, help='Build URL (No job info needed)')
 @click.option('--latest', type=bool, required=False, is_flag=True, help='Latest build (Replaces --number)')
 @click.pass_context
-def steps(ctx, debug, pretty, yaml, xml, toml, profile, list, name, job, number, url, latest):
+def steps(ctx, debug, **kwargs):
     """Get stage steps"""
     set_debug_log_level(debug)
-    if job or url:
-        cli_stage.steps(pretty, yaml, xml, toml, profile, list, name, job, number, url, latest)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_stage.steps(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
 
@@ -80,10 +94,10 @@ def steps(ctx, debug, pretty, yaml, xml, toml, profile, list, name, job, number,
               is_flag=False,
               help='Download logs to directory')
 @click.pass_context
-def logs(ctx, debug, profile, name, job, number, url, latest, download_dir):
+def logs(ctx, debug, **kwargs):
     """Stage logs"""
     set_debug_log_level(debug)
-    if job or url:
-        cli_stage.logs(profile, name, job, number, url, latest, download_dir)
+    if kwargs.get("job") or kwargs.get("url"):
+        cli_stage.logs(**translate_kwargs(kwargs))
     else:
         click.echo(ctx.get_help())
